using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using PhoenixDLL.GUI;
using PhoenixDLL.Class;
using PhoenixStatistics.Class;

namespace PhoenixCommander.GUI
{
    /// <summary>
    /// Phoenix Suite
    /// </summary>
    public partial class fr_Main : Form
    {
        #region Variables
        /// <summary>
        /// Informations sur les rendez-vous
        /// </summary>
        private MeetingSet vMeetingSet = new MeetingSet();

        /// <summary>
        /// Gestionnaire de statistiques
        /// </summary>
        private StatManager vStatManager = new StatManager();

        /// <summary>
        /// Agenda
        /// </summary>
        private PhoenixAgenda.GUI.fr_Main Cala;

        /// <summary>
        /// Fiches mdicales
        /// </summary>
        private PhoenixCards.GUI.fr_Main Pata;

        /// <summary>
        /// Photos
        /// </summary>
        private PhoenixPics.GUI.fr_Main Poto;

        /// <summary>
        /// Prescriptions
        /// </summary>
        private PhoenixPrescription.GUI.fr_Main Pega;

        /// <summary>
        /// Honoraires
        /// </summary>
        private PhoenixMoney.GUI.fr_Main Paga;

        /// <summary>
        /// Statistiques
        /// </summary>
        private PhoenixStatistics.GUI.fr_Main Stata;
        #endregion

        #region Constructeur
        /// <summary>
        /// Constructeur
        /// </summary>
        public fr_Main()
        {
            InitializeComponent();
        }
        #endregion

        #region Events
        
        /// <summary>
        /// Chargement de la fentre
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_FrameLoad(object sender, EventArgs e)
        {
            BringToFront();
        }
        /// <summary>
        /// Clique sur une demande de Calendrier
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_Cala(object sender, EventArgs e)
        {
            if (Cala == null || Cala.IsDisposed)
            {
                Cala = new PhoenixAgenda.GUI.fr_Main();
                Cala.MdiParent = this;
                Cala.MeetingSet = vMeetingSet;
                Cala.Show();                
            }
            else                           
                Cala.BringToFront();            
        }

        /// <summary>
        /// Clique sur une demande de fiche mdicale
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_Pata(object sender, EventArgs e)
        {
            if (Pata == null || Pata.IsDisposed)
            {
                Pata = new PhoenixCards.GUI.fr_Main();
                Pata.MdiParent = this;                
                Pata.Show();
            }
            else            
                Pata.BringToFront();            
        }

        /// <summary>
        /// Clique sur une demande de Photo
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_Poto(object sender, EventArgs e)
        {
            if (Poto == null || Poto.IsDisposed)
            {
                Poto = new PhoenixPics.GUI.fr_Main();
                Poto.MdiParent = this;                
                Poto.Show();
            }
            else            
                Poto.BringToFront();            
        }

        /// <summary>
        /// Clique sur une demande de prescription
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_Pega(object sender, EventArgs e)
        {
            if (Pega == null || Pega.IsDisposed)
            {
                Pega = new PhoenixPrescription.GUI.fr_Main();
                Pega.MdiParent = this;                
                Pega.Show();
            }
            else            
                Pega.BringToFront();            
        }

        /// <summary>
        /// Clique sur une demande d'honoraire
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_Paga(object sender, EventArgs e)
        {
            if (Paga == null || Paga.IsDisposed)
            {
                Paga = new PhoenixMoney.GUI.fr_Main();
                Paga.MdiParent = this;                
                Paga.Show();
            }
            else            
                Paga.BringToFront();            
        }
        
        /// <summary>
        /// Clique sur une demande de statistiques
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_Stata(object sender, EventArgs e)
        {
            if (Stata == null || Stata.IsDisposed)
            {
                Stata = new PhoenixStatistics.GUI.fr_Main();
                Stata.MdiParent = this;
                Stata.StatManager = vStatManager;
                Stata.Show();
            }
            else
                Stata.BringToFront();
        }
        #endregion

        #region Accesseurs
        /// <summary>
        /// Retourne ou initialise le MeetingSet des rendez-vous
        /// </summary>
        public MeetingSet MeetingSet { set { vMeetingSet = value; } get { return vMeetingSet; } }

        /// <summary>
        /// Retourne ou initialise le gestionnaire de statistiques
        /// </summary>
        public StatManager StatManager { set { vStatManager = value; } get { return vStatManager; } }
        #endregion
    }
}